@@ -28,6 +28,8 @@ use unicode_segmentation::UnicodeSegmentation;
 
 pub enum MarkMode {
     Delete,
+    #[cfg(feature = "trash-move")]
+    Trash,
 }
 
 pub type EntryMarkMap = BTreeMap<TreeIndex, EntryMark>;
@@ -108,7 +110,9 @@ impl MarkPane {
     pub fn process_events(mut self, key: Key) -> Option<(Self, Option<MarkMode>)> {
         let action = None;
         match key {
-            Ctrl('r') => return Some(self.prepare_deletion()),
+            Ctrl('r') => return Some(self.prepare_deletion(MarkMode::Delete)),
+            #[cfg(feature = "trash-move")]
+            Ctrl('t') => return Some(self.prepare_deletion(MarkMode::Trash)),
             Char('x') | Char('d') | Char(' ') => {
                 return self.remove_selected().map(|s| (s, action))
             }
@@ -177,12 +181,12 @@ impl MarkPane {
             d.num_errors_during_deletion = num_errors;
         }
     }
-    fn prepare_deletion(mut self) -> (Self, Option<MarkMode>) {
+    fn prepare_deletion(mut self, mark: MarkMode) -> (Self, Option<MarkMode>) {
         for entry in self.marked.values_mut() {
             entry.num_errors_during_deletion = 0;
         }
         self.selected = Some(0);
-        (self, Some(MarkMode::Delete))
+        (self, Some(mark))
     }
     fn remove_selected(mut self) -> Option<Self> {
         if let Some(mut selected) = self.selected {
@@ -358,6 +362,17 @@ impl MarkPane {
                 sub_modifier: Modifier::empty(),
             };
             Paragraph::new(Text::from(Spans::from(vec![
+                #[cfg(feature = "trash-move")]
+                Span::styled(
+                    " Ctrl + t",
+                    Style {
+                        fg: Color::White.into(),
+                        bg: Color::Black.into(),
+                        ..default_style
+                    },
+                ),
+                #[cfg(feature = "trash-move")]
+                Span::styled(" to trash or ", default_style),
                 Span::styled(
                     " Ctrl + r",
                     Style {
@@ -366,10 +381,7 @@ impl MarkPane {
                         ..default_style
                     },
                 ),
-                Span::styled(
-                    " deletes listed entries from disk without prompt",
-                    default_style,
-                ),
+                Span::styled(" to delete without prompt", default_style),
             ])))
             .style(default_style)
             .render(help_line_area, buf);
